@@ -58,6 +58,9 @@ GType		e_ews_folder_get_type (void);
 const gchar *	e_ews_folder_type_to_nick (EEwsFolderType folder_type);
 EEwsFolderType	e_ews_folder_type_from_nick (const gchar *folder_type_nick);
 EEwsFolder *	e_ews_folder_new_from_soap_parameter (ESoapParameter *param);
+EEwsFolder *	e_ews_folder_new_from_error (const GError *error);
+gboolean	e_ews_folder_is_error (EEwsFolder *folder);
+const GError *	e_ews_folder_get_error (EEwsFolder *folder);
 const gchar *	e_ews_folder_get_name (EEwsFolder *folder);
 void		e_ews_folder_set_name (EEwsFolder *folder, const gchar *new_name);
 void		e_ews_folder_set_parent_id (EEwsFolder *folder, EwsFolderId *fid);
